/**
 * Borland Sprite
 * 
 * This class will allow interaction of sprites
 * 
 */

import java.awt.Graphics;
import java.awt.Image;
import java.awt.*;
import javax.swing.*;
import java.applet.AudioClip;
import java.applet.Applet;

import java.util.HashMap;
public abstract class Sprite {

    public int x;  
    public int y;
    public int width;
    public int height;
    HashMap<String,Image> allImages = new HashMap<String,Image>();
    HashMap<String,AudioClip> allSounds = new HashMap<String,AudioClip>();
    
    /**
     * To create a sprite that is not an image
     */
    public Sprite(int x, int y, int width, int height) {
        super();
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
    }

    /**
     * To create a sprite with an image (saved in your bluej project folder
     */    
    public Sprite(int x, int y, int width, int height, String filename) {
        super();
        this.x = x;
        this.y = y;
        this.width = width;
        this.height = height;
        try
        {
            allImages.put(filename,javax.imageio.ImageIO.read(this.getClass().getResource(filename)));
        }
        catch (Exception e){
            System.out.println("trouble with loading image");
        }
    }
    /*
    public int loadImage(String fileName)
    {
    }
     */

    /**
     * To draw the sprite (if its an image) on what graphics layer you want
     */
    public void drawImage(Graphics g,String fileName)
    {   
        if (allImages.containsKey(fileName))
            drawImageNow(g,allImages.get(fileName));//,x,y,width,height,null);      
        else
        {
            try
            {
                Image loadImage=javax.imageio.ImageIO.read(this.getClass().getResource(fileName));
                allImages.put(fileName,loadImage);
                //g.drawImage(loadImage,x,y,0,0,25,25,width,height,null);  
                //g.drawImage(loadImage,x,y,width,height,null);      
                drawImageNow(g,loadImage);
            }
            catch (Exception e){
                System.out.println("trouble with loading image");
            }
        }

    }

    /**
     * To draw the sprite (if its an image) on what graphics layer you want
     */
    public void drawImage(Graphics g)
    {   
        for ( String key : allImages.keySet() )
        {
            //g.drawImage(allImages.get(key),x,y,null);      
            drawImageNow(g,allImages.get(key));
            return;
        }
    }
    
    public void drawImageNow(Graphics g,Image img){
         g.drawImage(img,x,y,width,height,null);
    }

    public void playSound(String filename)
    {
        if (allSounds.containsKey(filename))
            allSounds.get(filename).play();
        else
        {
            try
            {
                AudioClip  clip = Applet.newAudioClip(this.getClass().getResource(filename));
                allSounds.put(filename,clip);
                clip.play();
            }
            catch (Exception e){
                System.out.println("trouble with loading sound");
            }
        }
      
    }
    
    /**
     * To check if there is a collission between  this sprite and another one. 
     * returns true if there is a collission and false otherwise
     */
    public boolean isCollision(Sprite otherSprite)
    {
        if (x+width>=otherSprite.x && x<=otherSprite.x+otherSprite.width && y+height>=otherSprite.y && y<=otherSprite.y+otherSprite.height)
            return true;
        else
            return false;
    }

    /**
     * To check if there is a collission between two sprites
     * returns true if there is a collission and false otherwise
     * you would call it like:  if (Sprite.isCollision(mario, luigi))
     */    
    public static boolean isCollision(Sprite s1,Sprite s2)
    {
        return s1.isCollision(s2);
    }

    public int findRandom (int start, int end)
    {
        int multiplier = end-start+1;
        int random = (int) (Math.random()*multiplier)+start;
        return random;
    }

    public Color findRandomColor ()
    {
        int red= (int)(256 * Math.random());
        int green= (int)(256 * Math.random());
        int blue= (int)(256 * Math.random());
        Color randomColor=new Color(red,green,blue);
        return randomColor;
    }

    public void echo(String s)
    {
        System.out.println(s);
    }

    public void echo(int s)
    {
        System.out.println(s);
    }

    public void echo(double s)
    {
        System.out.println(s);
    }
}